@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from ssl import SSLContext, SSLObject
 from types import SimpleNamespace
-from typing import Any, Dict, List, Optional
+from typing import Any
 
 from sanic.models.protocol_types import TransportProtocol
 
@@ -21,6 +21,7 @@ class ConnInfo:
         "client",
         "client_ip",
         "ctx",
+        "lost",
         "peername",
         "server_port",
         "server",
@@ -33,21 +34,18 @@ class ConnInfo:
 
     def __init__(self, transport: TransportProtocol, unix=None):
         self.ctx = SimpleNamespace()
-        self.peername = None
+        self.lost = False
+        self.peername: tuple[str, int] | None = None
         self.server = self.client = ""
         self.server_port = self.client_port = 0
         self.client_ip = ""
         self.sockname = addr = transport.get_extra_info("sockname")
         self.ssl = False
         self.server_name = ""
-        self.cert: Dict[str, Any] = {}
-        self.network_paths: List[Any] = []
-        sslobj: Optional[SSLObject] = transport.get_extra_info(
-            "ssl_object"
-        )  # type: ignore
-        sslctx: Optional[SSLContext] = transport.get_extra_info(
-            "ssl_context"
-        )  # type: ignore
+        self.cert: dict[str, Any] = {}
+        self.network_paths: list[Any] = []
+        sslobj: SSLObject | None = transport.get_extra_info("ssl_object")  # type: ignore
+        sslctx: SSLContext | None = transport.get_extra_info("ssl_context")  # type: ignore
         if sslobj:
             self.ssl = True
             self.server_name = getattr(sslobj, "sanic_server_name", None) or ""
@@ -65,9 +63,7 @@ class ConnInfo:
             if addr[1] != (443 if self.ssl else 80):
                 self.server = f"{self.server}:{addr[1]}"
         self.peername = addr = transport.get_extra_info("peername")
-        self.network_paths = transport.get_extra_info(  # type: ignore
-            "network_paths"
-        )
+        self.network_paths = transport.get_extra_info("network_paths")  # type: ignore
 
         if isinstance(addr, tuple):
             self.client = addr[0] if len(addr) == 2 else f"[{addr[0]}]"
