@@ -1,13 +1,10 @@
 from __future__ import annotations
 
+from collections.abc import Iterable
 from typing import (
     TYPE_CHECKING,
     Any,
     Callable,
-    Iterable,
-    List,
-    Optional,
-    Union,
 )
 
 from sanic.models.handler_types import RouteHandler
@@ -115,22 +112,22 @@ class HTTPMethodView:
         to `"/v"`.
     """
 
-    get: Optional[Callable[..., Any]]
-
-    decorators: List[Callable[[Callable[..., Any]], Callable[..., Any]]] = []
+    decorators: list[Callable[[Callable[..., Any]], Callable[..., Any]]] = []
 
     def __init_subclass__(
         cls,
-        attach: Optional[Union[Sanic, Blueprint]] = None,
+        attach: Sanic | Blueprint | None = None,
         uri: str = "",
         methods: Iterable[str] = frozenset({"GET"}),
-        host: Optional[str] = None,
-        strict_slashes: Optional[bool] = None,
-        version: Optional[int] = None,
-        name: Optional[str] = None,
+        host: str | None = None,
+        strict_slashes: bool | None = None,
+        version: int | None = None,
+        name: str | None = None,
         stream: bool = False,
         version_prefix: str = "/v",
+        **kwargs: Any,
     ) -> None:
+        super().__init_subclass__(**kwargs)
         if attach:
             cls.attach(
                 attach,
@@ -146,9 +143,11 @@ class HTTPMethodView:
 
     def dispatch_request(self, request: Request, *args, **kwargs):
         """Dispatch request to appropriate handler method."""
-        handler = getattr(self, request.method.lower(), None)
-        if not handler and request.method == "HEAD":
-            handler = self.get
+        method = request.method.lower()
+        handler = getattr(self, method, None)
+
+        if not handler and method == "head":
+            handler = getattr(self, "get")
         if not handler:
             # The router will never allow us to get here, but this is
             # included as a fallback and for completeness.
@@ -203,13 +202,13 @@ class HTTPMethodView:
     @classmethod
     def attach(
         cls,
-        to: Union[Sanic, Blueprint],
+        to: Sanic | Blueprint,
         uri: str,
         methods: Iterable[str] = frozenset({"GET"}),
-        host: Optional[str] = None,
-        strict_slashes: Optional[bool] = None,
-        version: Optional[int] = None,
-        name: Optional[str] = None,
+        host: str | None = None,
+        strict_slashes: bool | None = None,
+        version: int | None = None,
+        name: str | None = None,
         stream: bool = False,
         version_prefix: str = "/v",
     ) -> None:
