@@ -1,15 +1,17 @@
 import logging
 import os
 import sys
-
 from collections import Counter
 from pathlib import Path
 from time import gmtime, strftime
+from urllib.parse import unquote
 
 import pytest
-
 from sanic import Sanic, text
 from sanic.exceptions import FileNotFound, ServerError
+from sanic.response import file
+
+pytestmark = pytest.mark.xdist_group(name="static_files")
 
 
 @pytest.fixture(scope="module")
@@ -58,9 +60,12 @@ def symlink(static_file_directory):
     )
     symlink = "symlink"
     dist = os.path.join(static_file_directory, symlink)
+    if os.path.islink(dist):
+        os.remove(dist)
     os.symlink(src, dist)
     yield symlink
-    os.remove(dist)
+    if os.path.exists(dist):
+        os.remove(dist)
 
 
 @pytest.fixture(autouse=True, scope="module")
@@ -70,9 +75,12 @@ def hard_link(static_file_directory):
     )
     hard_link = "hard_link"
     dist = os.path.join(static_file_directory, hard_link)
+    if os.path.exists(dist):
+        os.remove(dist)
     os.link(src, dist)
     yield hard_link
-    os.remove(dist)
+    if os.path.exists(dist):
+        os.remove(dist)
 
 
 @pytest.mark.parametrize(
@@ -120,7 +128,7 @@ def test_static_file_pathlib_relative_path_traversal(
         pytest.skip("Current working directory does not end with 'sanic'")
 
     file_path = "./tests/static/../static/"
-    app.static("/", file_path)
+    app.static("/", file_path, follow_external_symlink_files=True)
     _, response = app.test_client.get(f"/{file_name}")
     assert response.status == 200
     assert response.body == get_file_content(static_file_directory, file_name)
@@ -150,43 +158,53 @@ def test_static_file_invalid_path(app, static_file_directory, file_name):
     assert response.status == 404
 
 
-@pytest.mark.parametrize("file_name", ["test.html"])
-def test_static_file_content_type(app, static_file_directory, file_name):
-    app.static(
-        "/testing.file",
-        get_file_path(static_file_directory, file_name),
-        content_type="text/html; charset=utf-8",
-    )
+@pytest.mark.parametrize(
+    "file_name,expected_content_type",
+    [
+        ("decode me.txt", "text/plain; charset=utf-8"),
+        ("test.html", "text/html; charset=utf-8"),
+        ("python.png", "image/png"),
+        # Note: file() default for unknown types differs from app.static
+        ("test.file", "text/plain; charset=utf-8"),
+    ],
+)
+def test_file_response_content_type(
+    app: Sanic, file_name, expected_content_type, static_file_directory
+):
+    """Responses by file() rather than app.static."""
 
-    request, response = app.test_client.get("/testing.file")
+    @app.get("/files/<filename>")
+    def file_route(request, filename):
+        file_path = os.path.join(static_file_directory, filename)
+        file_path = os.path.abspath(unquote(file_path))
+        return file(file_path)
+
+    request, response = app.test_client.get(f"/files/{file_name}")
     assert response.status == 200
-    assert response.body == get_file_content(static_file_directory, file_name)
-    assert response.headers["Content-Type"] == "text/html; charset=utf-8"
+    assert response.headers["Content-Type"] == expected_content_type
 
 
 @pytest.mark.parametrize(
-    "file_name,expected",
+    "file_name,expected_content_type",
     [
-        ("test.html", "text/html; charset=utf-8"),
         ("decode me.txt", "text/plain; charset=utf-8"),
+        ("test.html", "text/html; charset=utf-8"),
+        ("python.png", "image/png"),
         ("test.file", "application/octet-stream"),
     ],
 )
-def test_static_file_content_type_guessed(
-    app, static_file_directory, file_name, expected
+def test_static_file_content_type(
+    app: Sanic, file_name, expected_content_type, static_file_directory
 ):
-    app.static(
-        "/testing.file",
-        get_file_path(static_file_directory, file_name),
-    )
+    """Test that file responses automatically include charset for text."""
 
-    request, response = app.test_client.get("/testing.file")
+    app.static("/", static_file_directory)
+    request, response = app.test_client.get(file_name)
     assert response.status == 200
-    assert response.body == get_file_content(static_file_directory, file_name)
-    assert response.headers["Content-Type"] == expected
+    assert response.headers["Content-Type"] == expected_content_type
 
 
-def test_static_file_content_type_with_charset(app, static_file_directory):
+def test_static_file_content_type_forced(app, static_file_directory):
     app.static(
         "/testing.file",
         get_file_path(static_file_directory, "decode me.txt"),
@@ -203,7 +221,11 @@ def test_static_file_content_type_with_charset(app, static_file_directory):
 )
 @pytest.mark.parametrize("base_uri", ["/static", "", "/dir"])
 def test_static_directory(app, file_name, base_uri, static_file_directory):
-    app.static(base_uri, static_file_directory)
+    app.static(
+        base_uri,
+        static_file_directory,
+        follow_external_symlink_files=(file_name == "symlink"),
+    )
 
     request, response = app.test_client.get(uri=f"{base_uri}/{file_name}")
     assert response.status == 200
@@ -520,7 +542,7 @@ def test_stack_trace_on_not_found(app, static_file_directory, caplog):
     assert counter[("sanic.root", logging.INFO)] == 10
     assert counter[("sanic.root", logging.ERROR)] == 0
     assert counter[("sanic.error", logging.ERROR)] == 0
-    assert counter[("sanic.server", logging.INFO)] == 3
+    assert counter[("sanic.server", logging.INFO)] == 4
 
 
 def test_no_stack_trace_on_not_found(app, static_file_directory, caplog):
@@ -539,7 +561,7 @@ def test_no_stack_trace_on_not_found(app, static_file_directory, caplog):
     assert counter[("sanic.root", logging.INFO)] == 10
     assert counter[("sanic.root", logging.ERROR)] == 0
     assert counter[("sanic.error", logging.ERROR)] == 0
-    assert counter[("sanic.server", logging.INFO)] == 3
+    assert counter[("sanic.server", logging.INFO)] == 4
     assert response.text == "No file: /static/non_existing_file.file"
 
 
